@@ -12,15 +12,22 @@
 #' @examples
 #' tmr_format(tmr_timer(61.66))
 #' tmr_format(tmr_timer(61.66), digits = 0)
-tmr_format <- function(x, digits = 3) {
+tmr_format <- function(x, digits = 3, ..., print_title = TRUE) {
   chk_digits(digits)
-  if(digits < 0) err("`digits` must not be negative.")
+  rlang::check_dots_empty()
+
+  if (digits < 0) err("`digits` must not be negative.")
 
   x <- tmr_round(x, digits = digits)
   msecs <- as.numeric(x) - floor(as.numeric(x))
   x <- tmr_floor(x)
+  title <- tmr_title(x)
   x <- as.character(x)
   msecs <- formatC(msecs, digits = digits, format = "f")
   msecs <- substr(msecs, 2, nchar(msecs))
-  paste0(x, msecs)
+  x <- paste0(x, msecs)
+  if (print_title) {
+    x <- paste_title(x, title)
+  }
+  x
 }
