@@ -15,6 +15,7 @@
 #' tmr_round(tmr_timer(121), -2) # 121 is rounded to 100 seconds
 tmr_round <- function(x, digits = 0) {
   start <- tmr_is_started(x)
+  title <- tmr_title(x)
   x <- round(as.numeric(tmr_elapsed(x)), digits = digits)
-  tmr_timer(x, start = start)
+  tmr_timer(x, start = start, title = title)
 }
